@@ -106,12 +106,16 @@ def sent_encode(tokenizer, sent):
     elif isinstance(tokenizer, GPT2Tokenizer):
         # for RoBERTa and GPT-2
         import transformers
+
         if LooseVersion(transformers.__version__) >= LooseVersion("3.0.0"):
-            return tokenizer.encode(sent, add_special_tokens=True, add_prefix_space=True, max_length=tokenizer.max_len, truncation=True)
+            return tokenizer.encode(
+                sent, add_special_tokens=True, add_prefix_space=True, max_length=tokenizer.max_len, truncation=True
+            )
         else:
             return tokenizer.encode(sent, add_special_tokens=True, add_prefix_space=True, max_length=tokenizer.max_len)
     else:
         import transformers
+
         if LooseVersion(transformers.__version__) >= LooseVersion("3.0.0"):
             return tokenizer.encode(sent, add_special_tokens=True, max_length=tokenizer.max_len, truncation=True)
         else:
@@ -437,12 +441,15 @@ def bert_cos_score_idf(
     return preds
 
 
-def get_hash(model, num_layers, idf, rescale_with_baseline):
+def get_hash(model, num_layers, idf, rescale_with_baseline, use_custom_baseline):
     msg = "{}_L{}{}_version={}(hug_trans={})".format(
         model, num_layers, "_idf" if idf else "_no-idf", __version__, trans_version
     )
     if rescale_with_baseline:
-        msg += "-rescaled"
+        if use_custom_baseline:
+            msg += "-custom-rescaled"
+        else:
+            msg += "-rescaled"
     return msg
 
 
